@@ -153,9 +153,11 @@
 #include "ipc.h"
 #include "service.h"
 #include "objdb.h"
-#include "print.h"
+#include "logsys.h"
 #include "sync.h"
 
+LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+
 #ifdef AMFTEST
 #define static
 #endif
@@ -733,7 +735,7 @@ static int create_cluster_model (void)
 		return -1;
 	}
 
-	this_amf_node->nodeid = this_ip->nodeid;
+	this_amf_node->nodeid = totempg_my_nodeid_get();
 
 	return 0;
 }
@@ -754,7 +756,7 @@ static unsigned int calc_sync_master (
 	unsigned int *member_list, int member_list_entries)
 {
 	int i;
-	unsigned int master = this_ip->nodeid; /* assume this node is master */
+	unsigned int master = totempg_my_nodeid_get(); /* assume this node is master */
 
 	for (i = 0; i < member_list_entries; i++) {
 		if (member_list[i] < master &&
@@ -1156,7 +1158,7 @@ static void amf_sync_init (void)
 			break;
 	}
 
-	if (scsm.state == SYNCHRONIZING && scsm.sync_master == this_ip->nodeid) {
+	if (scsm.state == SYNCHRONIZING && scsm.sync_master == totempg_my_nodeid_get()) {
 		amf_msg_mcast (MESSAGE_REQ_EXEC_AMF_SYNC_START, NULL, 0);
 		assert (amf_cluster != NULL);
 		scsm.cluster = amf_cluster;
@@ -1192,7 +1194,7 @@ static int amf_sync_process (void)
 {
 	SYNCTRACE ("state %s", scsm_state_names[scsm.state]);
 
-	if (scsm.state != SYNCHRONIZING || scsm.sync_master != this_ip->nodeid) {
+	if (scsm.state != SYNCHRONIZING || scsm.sync_master != totempg_my_nodeid_get()) {
 		return 0;
 	}
 
@@ -1273,7 +1275,7 @@ static void amf_sync_activate (void)
 			this_amf_node = get_this_node_obj ();
 			sync_state_set (NORMAL_OPERATION);
 			if (this_amf_node != NULL) {
-				this_amf_node->nodeid = this_ip->nodeid;
+				this_amf_node->nodeid = totempg_my_nodeid_get();
 				cluster_joined_nodes_start ();
 			} else {
 				log_printf (LOG_LEVEL_INFO,
@@ -1305,8 +1307,6 @@ static void amf_sync_activate (void)
  */
 static int amf_exec_init_fn (struct objdb_iface_ver0 *objdb)
 {
-	log_init ("AMF");
-
 	if (gethostname (hostname, sizeof (hostname)) == -1) {
 		log_printf (LOG_LEVEL_ERROR, "gethostname failed: %d", errno);
 		openais_exit_error (AIS_DONE_FATAL_ERR);
@@ -1319,15 +1319,6 @@ static int amf_exec_init_fn (struct objdb_iface_ver0 *objdb)
 
 	sync_state_set (IDLE);
 
-	amf_cluster_init();
-	amf_node_init();
-	amf_application_init();
-	amf_sg_init();
-	amf_su_init();
-	amf_comp_init();
-	amf_si_init();
-	amf_util_init ();
-
 	return (0);
 }
 
@@ -1388,7 +1379,7 @@ static void amf_confchg_fn (
 			}
 			break;
 		case SYNCHRONIZING: {
-			if (joined_list_entries > 0 && scsm.sync_master == this_ip->nodeid) {
+			if (joined_list_entries > 0 && scsm.sync_master == totempg_my_nodeid_get()) {
 				/* restart sync */
 				amf_msg_mcast (MESSAGE_REQ_EXEC_AMF_SYNC_START, NULL, 0);
 			}
@@ -1400,7 +1391,7 @@ static void amf_confchg_fn (
 				scsm.sync_master =
 					calc_sync_master (member_list, member_list_entries);
 
-				if (scsm.sync_master == this_ip->nodeid) {
+				if (scsm.sync_master == totempg_my_nodeid_get()) {
 					/* restart sync */
 					SYNCTRACE ("I am (new) sync master");
 					amf_msg_mcast (MESSAGE_REQ_EXEC_AMF_SYNC_START, NULL, 0);
@@ -1416,7 +1407,7 @@ static void amf_confchg_fn (
 				scsm.sync_master =
 					calc_sync_master (member_list, member_list_entries);
 
-				if (scsm.sync_master == this_ip->nodeid) {
+				if (scsm.sync_master == totempg_my_nodeid_get()) {
 					SYNCTRACE ("I am (new) sync master");
 				}
 			}
@@ -1662,7 +1653,7 @@ static void message_handler_req_exec_amf_sync_start (
 			scsm.sync_master = nodeid;
 			break;
 		case PROBING_2:
-			if (this_ip->nodeid == nodeid) {
+			if (totempg_my_nodeid_get() == nodeid) {
 				scsm.sync_master = nodeid;
 				sync_state_set (CREATING_CLUSTER_MODEL);
 				if (create_cluster_model() == 0) {
@@ -1925,12 +1916,77 @@ static void message_handler_req_lib_amf_pmstart (
 	void *conn,
 	void *msg)
 {
+	struct req_lib_amf_pmstart *req_lib = msg;
+	struct res_lib_amf_pmstart  res_lib;
+	struct amf_comp *comp;
+	SaAisErrorT error = SA_AIS_OK;
+
+	TRACE2("PmStart msg: '%s', %llu %d %d %d",
+				req_lib->compName.value, 
+				req_lib->processId,
+				req_lib->descendentsTreeDepth,
+				req_lib->pmErrors,
+				req_lib->recommendedRecovery);
+
+	comp = amf_comp_find (amf_cluster, &req_lib->compName);
+
+	if (comp != NULL) {
+		comp->conn = conn;
+
+		error = amf_comp_pm_start (comp, req_lib->processId,
+								   req_lib->descendentsTreeDepth,
+								   req_lib->pmErrors,
+								   req_lib->recommendedRecovery);
+	} else {
+		log_printf (LOG_ERR, "PmStart: Component '%s' not found",
+					req_lib->compName.value);
+		error = SA_AIS_ERR_NOT_EXIST;
+	}
+
+	res_lib.header.id = MESSAGE_RES_AMF_PMSTART;
+	res_lib.header.size = sizeof (res_lib);
+	res_lib.header.error = error;
+	openais_conn_send_response (conn, &res_lib,
+								sizeof (struct res_lib_amf_pmstart));
+
 }
 
 static void message_handler_req_lib_amf_pmstop (
 	void *conn,
 	void *msg)
 {
+	struct req_lib_amf_pmstop *req_lib = msg;
+	struct res_lib_amf_pmstop  res_lib;
+	struct amf_comp *comp;
+	SaAisErrorT error = SA_AIS_OK;
+
+	TRACE2 ("PmStop msg: '%s', %llu %d %d",
+			req_lib->compName.value, 
+			req_lib->processId,
+			req_lib->stopQualifier,
+			req_lib->pmErrors);
+
+	comp = amf_comp_find (amf_cluster, &req_lib->compName);
+
+	if (comp != NULL) {
+		comp->conn = conn;
+
+		error = amf_comp_pm_stop (comp,
+								  req_lib->stopQualifier,
+								  req_lib->processId,
+								  req_lib->pmErrors);
+	} else {
+		log_printf (LOG_ERR, "PmStop: Component '%s' not found",
+					req_lib->compName.value);
+		error = SA_AIS_ERR_NOT_EXIST;
+	}
+
+	res_lib.header.id = MESSAGE_RES_AMF_PMSTOP;
+	res_lib.header.size = sizeof (res_lib);
+	res_lib.header.error = error;
+	openais_conn_send_response (conn, &res_lib,
+								sizeof (struct res_lib_amf_pmstop));
+
 }
 
 static void message_handler_req_lib_amf_healthcheckstart (
@@ -2153,6 +2209,36 @@ static void message_handler_req_lib_amf_protectiongrouptrackstop (
 #endif
 }
 
+/**
+ * multicast a message out reporting a component error
+ * (to be called by passive monitoring)
+ */
+void mcast_error_report_from_pm (
+    struct amf_comp *comp,
+    SaAmfRecommendedRecoveryT recommendedRecovery)
+{
+	struct req_exec_amf_comp_error_report req_exec;
+	struct iovec iovec;
+	SaNameT erroneous_comp_name;
+
+	amf_comp_dn_make(comp, &erroneous_comp_name);
+
+	TRACE2("%s %s",comp->name.value, erroneous_comp_name.value);
+
+	req_exec.header.size = sizeof (struct req_exec_amf_comp_error_report);
+	req_exec.header.id = SERVICE_ID_MAKE (AMF_SERVICE,
+			MESSAGE_REQ_EXEC_AMF_COMPONENT_ERROR_REPORT);
+
+	memcpy (&req_exec.erroneousComponent, &erroneous_comp_name, sizeof (SaNameT));
+	memcpy (&req_exec.recommendedRecovery, &recommendedRecovery, sizeof (SaAmfRecommendedRecoveryT));
+
+	iovec.iov_base = (char *)&req_exec;
+	iovec.iov_len = sizeof (req_exec);
+
+	totempg_groups_mcast_joined (openais_group_handle, 
+								 &iovec, 1, TOTEMPG_AGREED);
+
+}
 
 static void message_handler_req_lib_amf_componenterrorreport (
 	void *conn,
