@@ -206,6 +206,7 @@ typedef enum {
 struct amf_si_assignment;
 struct amf_csi_assignment;
 struct amf_healthcheck;
+struct amf_pm;
 
 typedef enum {
 	CLUSTER_AC_UNINSTANTIATED = 1,
@@ -453,6 +454,7 @@ typedef struct amf_comp {
 	void *conn;
 	enum clc_component_types comptype;
 	struct amf_healthcheck *healthcheck_head;
+	struct list_head pm_head;
 	poll_timer_handle instantiate_timeout_handle;
 	poll_timer_handle cleanup_timeout_handle;
 	/*
@@ -481,6 +483,19 @@ typedef struct amf_healthcheck {
 
 } amf_healthcheck_t;
 
+
+typedef struct amf_pm {
+       /* Configuration Attributes */
+       SaUint64T pid;
+       SaAmfPmErrorsT errors;
+       SaAmfRecommendedRecoveryT recovery;
+
+       /* Implementation */
+	   struct list_head entry;
+       poll_timer_handle timer_handle_period;
+} amf_pm_t;
+
+
 typedef struct amf_si {
 	/* Configuration Attributes */
 	SaNameT name;
@@ -649,13 +664,16 @@ struct req_exec_amf_cluster_start_tmo {
 extern struct amf_cluster *amf_config_read (char **error_string);
 extern void amf_runtime_attributes_print (struct amf_cluster *cluster);
 extern int amf_enabled (struct objdb_iface_ver0 *objdb);
-extern void *_amf_malloc (size_t size, char *file, unsigned int line);
-extern void *_amf_realloc (void* ptr, size_t size, char *file, unsigned int line);
+extern void *_amf_malloc (size_t size, const char *file, unsigned int line);
 #define amf_malloc(size) _amf_malloc ((size), __FILE__, __LINE__)
-extern void *_amf_calloc (size_t nmemb, size_t size, char *file,
+extern void *_amf_realloc (void* ptr, size_t size, const char *file, 
+	unsigned int line);
+#define amf_realloc(ptr,size) _amf_realloc ((ptr), (size), __FILE__, __LINE__)
+extern void *_amf_calloc (size_t nmemb, size_t size, const char *file,
 	unsigned int line);
 #define amf_calloc(nmemb,size) _amf_calloc ((nmemb), (size), __FILE__, __LINE__)
-#define amf_realloc(ptr,size) _amf_realloc ((ptr), (size), __FILE__, __LINE__)
+extern char *_amf_strdup (const char *str, const char *file, unsigned int line);
+#define amf_strdup(str) _amf_strdup(str, __FILE__, __LINE__)
 
 extern const char *amf_admin_state (int state);
 extern const char *amf_op_state (int state);
@@ -681,7 +699,6 @@ extern char *amf_deserialize_SaUint32T (char *buf, SaUint32T *num);
 extern char *amf_deserialize_SaUint64T (char *buf, SaUint64T *num);
 extern char *amf_deserialize_opaque (char *buf, void *dst, int *cnt);
 extern int amf_msg_mcast (int msg_id, void *buf, size_t len);
-extern void amf_util_init (void);
 extern void amf_fifo_put (int entry_type, amf_fifo_t **root, 
 	int size_of_data, void *data);
 extern int amf_fifo_get (amf_fifo_t **root, void *data);
@@ -692,7 +709,6 @@ extern void amf_call_function_asynchronous (async_func_t async_func, void *param
 
 /* General methods */
 extern struct amf_node *amf_node_new (struct amf_cluster *cluster, char *name);
-extern void amf_node_init (void);
 extern void *amf_node_serialize (struct amf_node *node, int *len);
 extern struct amf_node *amf_node_deserialize (
 	struct amf_cluster *cluster, char *buf);
@@ -734,7 +750,6 @@ extern void timer_function_node_probation_period_expired (void *node);
 /* amfcluster.c */
 
 /* General methods */
-extern void amf_cluster_init (void);
 extern struct amf_cluster *amf_cluster_new (void);
 extern void *amf_cluster_serialize (struct amf_cluster *cluster, int *len);
 extern struct amf_cluster *amf_cluster_deserialize (char *buf);
@@ -767,7 +782,6 @@ extern void amf_cluster_application_workload_assigned (
 /* amfapp.c */
 
 /* General methods */
-extern void amf_application_init (void);
 extern struct amf_application *amf_application_find (
 	struct amf_cluster *cluster, char *name);
 extern struct amf_application *amf_application_new (
@@ -797,7 +811,6 @@ extern void amf_application_sg_assigned (
 /* amfsg.c */
 
 /* General methods */
-extern void amf_sg_init (void);
 extern struct amf_sg *amf_sg_find (struct amf_application *app, char *name);
 extern struct amf_sg *amf_sg_new (struct amf_application *app, char *name);
 extern void amf_sg_delete (struct amf_sg *sg);
@@ -844,7 +857,6 @@ extern void amf_sg_si_activated (
 /* amfsu.c */
 
 /* General methods */
-extern void amf_su_init (void);
 extern struct amf_su *amf_su_find (
 	struct amf_cluster *cluster, SaNameT *name);
 extern struct amf_su *amf_su_new (struct amf_sg *sg, char *name);
@@ -900,7 +912,6 @@ extern int amf_su_instantiate (struct amf_su *su);
 /* amfcomp.c */
 
 /* General methods */
-extern void amf_comp_init (void);
 extern struct amf_comp *amf_comp_new (struct amf_su *su, char *name);
 extern void amf_comp_delete (struct amf_comp *comp);
 extern char *amf_comp_dn_make (struct amf_comp *comp, SaNameT *name);
@@ -977,6 +988,17 @@ extern SaAisErrorT amf_comp_healthcheck_start (
 extern SaAisErrorT amf_comp_healthcheck_stop (
 	struct amf_comp *comp,
 	SaAmfHealthcheckKeyT *healthcheckKey);
+extern SaAisErrorT amf_comp_pm_start (
+	struct amf_comp *comp,
+	SaUint64T pid,
+	SaInt32T depth,
+	SaAmfPmErrorsT pmErrors,
+	SaAmfRecommendedRecoveryT recommendedRecovery);
+extern SaAisErrorT amf_comp_pm_stop (
+	struct amf_comp *comp,
+	SaAmfPmStopQualifierT stopQualifier,
+	SaInt64T pid,
+	SaAmfPmErrorsT pmErrors);
 extern SaAisErrorT amf_comp_register (struct amf_comp *comp);
 extern void amf_comp_unregister (struct amf_comp *comp);
 extern void amf_comp_error_report (
@@ -1009,11 +1031,14 @@ extern void amf_comp_error_suspected_clear (amf_comp_t *comp);
 extern void amf_comp_error_suspected_set (amf_comp_t *comp);
 extern int amf_comp_is_error_suspected (amf_comp_t *comp);
 
+extern void mcast_error_report_from_pm (
+    struct amf_comp *comp,
+    SaAmfRecommendedRecoveryT recommendedRecovery);
+
 /*===========================================================================*/
 /* amfsi.c */
 
 /* General methods */
-extern void amf_si_init (void);
 extern struct amf_si *amf_si_find (struct amf_application *app, char *name);
 extern struct amf_si *amf_si_new (struct amf_application *app, char *name);
 extern void amf_si_delete (struct amf_si *si);
