@@ -143,12 +143,14 @@
 #include <stdlib.h>
 #include <errno.h>
 
-#include "print.h"
+#include "logsys.h"
 #include "amf.h"
 #include "util.h"
 #include "main.h"
 #include "service.h"
 
+LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+
 typedef struct cluster_event {
 	amf_cluster_event_type_t event_type;
 	amf_cluster_t *cluster;
@@ -495,11 +497,6 @@ void amf_cluster_application_workload_assigned (
  * General methods
  *****************************************************************************/
 
-void amf_cluster_init (void)
-{
-	log_init ("AMF");
-}
-
 struct amf_cluster *amf_cluster_new (void) 
 {
 	struct amf_cluster *cluster = amf_calloc (1, 
