@@ -366,10 +366,12 @@
 #include <errno.h>
 
 #include "amf.h"
-#include "print.h"
+#include "logsys.h"
 #include "main.h"
 #include "util.h"
 
+LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+
 static int assign_si (struct amf_sg *sg, int dependency_level);
 static void acsm_enter_activating_standby (struct amf_sg *sg);
 static void delete_si_assignments_in_scope (struct amf_sg *sg);
@@ -2701,11 +2703,6 @@ static void standby_su_activated_cbfn (
  * General methods
  *****************************************************************************/
 
-void amf_sg_init (void)
-{
-	log_init ("AMF");
-}
-
 /**
  * Constructor for SG objects. Adds SG to the list owned by
  * the specified application. Always returns a valid SG
