@@ -370,6 +370,7 @@
  *
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
 #include <string.h>
@@ -377,9 +378,11 @@
 
 #include "amf.h"
 #include "util.h"
-#include "print.h"
+#include "logsys.h"
 #include "main.h"
 
+LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+
 static int terminate_all_components_in_level (struct amf_su *su, 
 	SaUint32T current_instantiation_level);
 static int are_all_comps_in_level_uninst_or_term_failed (struct amf_su *su);
@@ -1357,11 +1360,6 @@ static void si_ha_state_assumed_cbfn (
  * General methods
  *****************************************************************************/
 
-void amf_su_init (void)
-{
-	log_init ("AMF");
-}
-
 /**
  * Constructor for SU objects. Adds SU last in the ordered
  * list owned by the specified SG. Always returns a
