@@ -62,9 +62,11 @@
 #include "totempg.h"
 #include "mempool.h"
 #include "util.h"
-#include "print.h"
+#include "logsys.h"
 #include "main.h"
 
+LOGSYS_DECLARE_SUBSYS ("AMF", LOG_INFO);
+
 enum cfg_message_req_types {
         MESSAGE_REQ_EXEC_CFG_RINGREENABLE = 0
 };
@@ -226,9 +228,9 @@ struct req_exec_cfg_ringreenable {
 
 static int cfg_exec_init_fn (struct objdb_iface_ver0 *objdb)
 {
-	log_init ("CFG");
 	return (0);
 }
+
 static void cfg_confchg_fn (
 	enum totem_configuration_type configuration_type,
 	unsigned int *member_list, int member_list_entries,
@@ -299,7 +301,7 @@ static void message_handler_req_lib_cfg_ringstatusget (
 	res_lib_cfg_ringstatusget.header.error = SA_AIS_OK;
 
 	totempg_ifaces_get (
-		this_ip->nodeid,
+		totempg_my_nodeid_get(),
 		interfaces,
 		&status,
 		&iface_count);
