@@ -70,7 +70,9 @@
 #include "swab.h"
 #include "ipc.h"
 #include "flow.h"
-#include "print.h"
+#include "logsys.h"
+
+LOGSYS_DECLARE_SUBSYS ("CPG", LOG_INFO);
 
 #define GROUP_HASH_SIZE 32
 
@@ -174,6 +176,8 @@ static void message_handler_req_lib_cpg_trackstart (void *conn, void *message);
 
 static void message_handler_req_lib_cpg_trackstop (void *conn, void *message);
 
+static void message_handler_req_lib_cpg_local_get (void *conn, void *message);
+
 static int cpg_node_joinleave_send (struct group_info *gi, struct process_info *pi, int fn, int reason);
 
 static int cpg_exec_send_joinlist(void);
@@ -222,6 +226,12 @@ static struct openais_lib_handler cpg_lib_service[] =
 		.response_size				= sizeof (struct res_lib_cpg_trackstart),
 		.response_id				= MESSAGE_RES_CPG_TRACKSTOP,
 		.flow_control				= OPENAIS_FLOW_CONTROL_NOT_REQUIRED
+	},
+	{ /* 6 */
+		.lib_handler_fn				= message_handler_req_lib_cpg_local_get,
+		.response_size				= sizeof (struct res_lib_cpg_local_get),
+		.response_id				= MESSAGE_RES_CPG_LOCAL_GET,
+		.flow_control				= OPENAIS_FLOW_CONTROL_NOT_REQUIRED
 	}
 };
 
@@ -457,8 +467,6 @@ static int cpg_exec_init_fn (struct objdb_iface_ver0 *objdb)
 {
 	int i;
 
-	log_init ("CPG");
-
 	for (i=0; i<GROUP_HASH_SIZE; i++) {
 		list_init(&group_lists[i]);
 	}
@@ -476,7 +484,7 @@ static int cpg_lib_exit_fn (void *conn)
 
 	if (gi) {
 		notify_info.pid = pi->pid;
-		notify_info.nodeid = this_ip->nodeid;
+		notify_info.nodeid = totempg_my_nodeid_get();
 		notify_info.reason = CONFCHG_CPG_REASON_PROCDOWN;
 		cpg_node_joinleave_send(gi, pi, MESSAGE_REQ_EXEC_CPG_PROCLEAVE, CONFCHG_CPG_REASON_PROCDOWN);
 		list_del(&pi->list);
@@ -622,8 +630,8 @@ static void cpg_confchg_fn (
 				lowest_nodeid = member_list[i];
 		}
 
-		log_printf(LOG_LEVEL_DEBUG, "confchg, low nodeid=%d, us = %d\n", lowest_nodeid, this_ip->nodeid);
-		if (lowest_nodeid == this_ip->nodeid) {
+		log_printf(LOG_LEVEL_DEBUG, "confchg, low nodeid=%d, us = %d\n", lowest_nodeid, totempg_my_nodeid_get());
+		if (lowest_nodeid == totempg_my_nodeid_get()) {
 
 			req_exec_cpg_downlist.header.id = SERVICE_ID_MAKE(CPG_SERVICE, MESSAGE_REQ_EXEC_CPG_DOWNLIST);
 			req_exec_cpg_downlist.header.size = sizeof(struct req_exec_cpg_downlist);
@@ -718,7 +726,7 @@ static void do_proc_join(
 		if (pi->pid == pid && pi->nodeid == nodeid) {
 
 			/* It could be a local join message */
-			if ((nodeid == this_ip->nodeid) &&
+			if ((nodeid == totempg_my_nodeid_get()) &&
 				(!pi->flags & PI_FLAG_MEMBER)) {
 				goto local_join;
 			} else {
@@ -831,6 +839,8 @@ static void message_handler_req_exec_cpg_procleave (
 			list_del(&pi->list);
 			if (!pi->conn)
 				free(pi);
+			else
+				pi->pid = 0;
 
 			if (list_empty(&gi->members)) {
 				remove_group(gi);
@@ -853,7 +863,7 @@ static void message_handler_req_exec_cpg_joinlist (
 		nodeid);
 
 	/* Ignore our own messages */
-	if (nodeid == this_ip->nodeid) {
+	if (nodeid == totempg_my_nodeid_get()) {
 		return;
 	}
 
@@ -932,7 +942,7 @@ static int cpg_exec_send_joinlist(void)
 			gi = list_entry(iter, struct group_info, list);
 			for (iter2 = gi->members.next; iter2 != &gi->members; iter2 = iter2->next) {
 				struct process_info *pi = list_entry(iter2, struct process_info, list);
-				if (pi->pid && pi->nodeid == this_ip->nodeid) {
+				if (pi->pid && pi->nodeid == totempg_my_nodeid_get()) {
 					count++;
 				}
 			}
@@ -959,7 +969,7 @@ static int cpg_exec_send_joinlist(void)
 			for (iter2 = gi->members.next; iter2 != &gi->members; iter2 = iter2->next) {
 
 				struct process_info *pi = list_entry(iter2, struct process_info, list);
-				if (pi->pid && pi->nodeid == this_ip->nodeid) {
+				if (pi->pid && pi->nodeid == totempg_my_nodeid_get()) {
 					memcpy(&jle->group_name, &gi->group_name, sizeof(mar_cpg_name_t));
 					jle->pid = pi->pid;
 					jle++;
@@ -1018,7 +1028,7 @@ static void message_handler_req_lib_cpg_join (void *conn, void *message)
 		pi);
 
 	/* Add a node entry for us */
-	pi->nodeid = this_ip->nodeid;
+	pi->nodeid = totempg_my_nodeid_get();
 	pi->pid = req_lib_cpg_join->pid;
 	pi->group = gi;
 	list_add(&pi->list, &gi->members);
@@ -1194,3 +1204,16 @@ tstop_ret:
 	res_lib_cpg_trackstop.header.error = SA_AIS_OK;
 	openais_conn_send_response(conn, &res_lib_cpg_trackstop.header, sizeof(res_lib_cpg_trackstop));
 }
+
+static void message_handler_req_lib_cpg_local_get (void *conn, void *message)
+{
+	struct res_lib_cpg_local_get res_lib_cpg_local_get;
+
+	res_lib_cpg_local_get.header.size = sizeof(res_lib_cpg_local_get);
+	res_lib_cpg_local_get.header.id = MESSAGE_RES_CPG_LOCAL_GET;
+	res_lib_cpg_local_get.header.error = SA_AIS_OK;
+	res_lib_cpg_local_get.local_nodeid = totempg_my_nodeid_get ();
+
+	openais_conn_send_response(conn, &res_lib_cpg_local_get,
+		sizeof(res_lib_cpg_local_get));
+}
