@@ -46,13 +46,16 @@
 #include <assert.h>
 #include <pthread.h>
 
+#include "swab.h"
 #include "flow.h"
 #include "totem.h"
 #include "totempg.h"
-#include "print.h"
+#include "logsys.h"
 #include "hdb.h"
 #include "../include/list.h"
 
+LOGSYS_DECLARE_SUBSYS ("FLOW", LOG_INFO);
+
 struct flow_control_instance {
 	struct list_head list_head;
 	unsigned int service;
@@ -244,8 +247,6 @@ unsigned int openais_flow_control_initialize (void)
 {
 	unsigned int res;
 
-	log_init ("FLOW");
-
 	res = totempg_groups_initialize (
 		&flow_control_handle,
 		flow_control_deliver_fn,
