@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2002-2006 MontaVista Software, Inc.
- * Copyright (c) 2006 Red Hat, Inc.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -58,6 +58,7 @@
 #include <ucred.h>
 #endif
 
+#include "swab.h"
 #include "../include/saAis.h"
 #include "../include/list.h"
 #include "../include/queue.h"
@@ -78,10 +79,12 @@
 #include "config.h"
 #include "tlist.h"
 #define LOG_SERVICE LOG_SERVICE_IPC
-#include "print.h"
+#include "logsys.h"
 
 #include "util.h"
 
+LOGSYS_DECLARE_SUBSYS ("IPC", LOG_INFO);
+
 #ifdef OPENAIS_SOLARIS
 #define MSG_NOSIGNAL 0
 #endif
@@ -101,8 +104,6 @@
 
 static unsigned int g_gid_valid = 0;
 
-static struct totem_ip_address *my_ip;
-
 static totempg_groups_handle ipc_handle;
 
 DECLARE_LIST_INIT (conn_info_list_head);
@@ -376,12 +377,15 @@ static void conn_info_destroy (struct conn_info *conn_info)
 	
 	pthread_attr_destroy (&conn_info->thread_attr);
 	pthread_mutex_destroy (&conn_info->mutex);
-	
+	pthread_mutex_destroy (&conn_info->flow_control_mutex);
+
 	list_del (&conn_info->list);
 	free (conn_info);
 }
 
-static int libais_connection_active (struct conn_info *conn_info)
+int libais_connection_active (struct conn_info *conn_info);
+
+int libais_connection_active (struct conn_info *conn_info)
 {
 	return (conn_info->state == CONN_STATE_ACTIVE);
 }
@@ -992,7 +996,7 @@ int message_source_is_local(mar_message_source_t *source)
 	int ret = 0;
 
 	assert (source != NULL);
-	if (source->nodeid == my_ip->nodeid) {
+	if (source->nodeid == totempg_my_nodeid_get ()) {
 		ret = 1;
 	}
 	return ret;
@@ -1003,7 +1007,8 @@ void message_source_set (
 	void *conn)
 {
 	assert ((source != NULL) && (conn != NULL));
-	source->nodeid = my_ip->nodeid;
+	memset (source, 0, sizeof (mar_message_source_t));
+	source->nodeid = totempg_my_nodeid_get ();
 	source->conn = conn;
 }
 
@@ -1019,15 +1024,12 @@ static void ipc_confchg_fn (
 void openais_ipc_init (
 	void (*serialize_lock_fn) (void),
 	void (*serialize_unlock_fn) (void),
-	unsigned int gid_valid,
-	struct totem_ip_address *my_ip_in)
+	unsigned int gid_valid)
 {
 	int libais_server_fd;
 	struct sockaddr_un un_addr;
 	int res;
 
-	log_init ("IPC");
-
 	ipc_serialize_lock_fn = serialize_lock_fn;
 
 	ipc_serialize_unlock_fn = serialize_unlock_fn;
@@ -1077,8 +1079,6 @@ void openais_ipc_init (
 
 	g_gid_valid = gid_valid;
 
-	my_ip = my_ip_in;
-
 	/*
 	 * Reset internal state of flow control when
 	 * configuration change occurs
@@ -1260,44 +1260,6 @@ retry_sendmsg_two:
 	return (0);
 }
 
-int openais_ipc_timer_add (
-	void *conn,
-	void (*timer_fn) (void *data),
-	void *data,
-	unsigned int msec_in_future,
-	timer_handle *handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-	int res;
-
-	res = timerlist_add_future (
-		&conn_info->timerlist,
-		timer_fn,
-		data,
-		msec_in_future,
-		handle);
-
-	return (res);
-}
-
-void openais_ipc_timer_del (
-	void *conn,
-	timer_handle timer_handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-
-	timerlist_del (&conn_info->timerlist, timer_handle);
-}
-
-void openais_ipc_timer_del_data (
-	void *conn,
-	timer_handle timer_handle)
-{
-	struct conn_info *conn_info = (struct conn_info *)conn;
-
-	timerlist_del (&conn_info->timerlist, timer_handle);
-}
-
 void openais_ipc_flow_control_create (
 	void *conn,
 	unsigned int service,
