@@ -48,6 +48,7 @@
 #include <signal.h>
 #include <arpa/inet.h>
 
+#include "swab.h"
 #include "service.h"
 #include "../include/saAis.h"
 #include "../include/saLck.h"
@@ -60,8 +61,9 @@
 #include "main.h"
 #include "ipc.h"
 #include "totempg.h"
-#include "print.h"
+#include "logsys.h"
 
+LOGSYS_DECLARE_SUBSYS ("LCK", LOG_INFO);
 
 enum lck_message_req_types {
 	MESSAGE_REQ_EXEC_LCK_RESOURCEOPEN = 0,
@@ -674,8 +676,6 @@ void lck_resource_cleanup_remove (
 
 static int lck_exec_init_fn (struct objdb_iface_ver0 *objdb)
 {
-	log_init ("LCK");
-
 	/*
 	 *  Initialize the saved ring ID.
 	 */
@@ -1069,11 +1069,13 @@ void unlock_algorithm (
 	if (resource_lock == resource->ex_granted) {
 		resource->ex_granted = 0;
 	}
-
-	/*
-	 * Delete resource lock from whichever list it is on
-	 */
-	list_del (&resource_lock->list);
+	else {
+		/*
+		 * Delete resource lock from whichever list it is on
+		 */
+		list_del (&resource_lock->list);
+	}
+	list_del (&resource_lock->resource_list);
 
 	/*
 	 * Check if EX locks are available, if so assign one
@@ -1279,13 +1281,14 @@ error_exit:
 			res_lib_lck_resourceunlockasync.header.error = error;
 			res_lib_lck_resourceunlockasync.invocation =
 				req_exec_lck_resourceunlock->invocation;
+			res_lib_lck_resourceunlockasync.lockId = req_exec_lck_resourceunlock->lock_id;
 
 			openais_conn_send_response (
-				req_exec_lck_resourceunlock->source.conn,
+				openais_conn_partner_get(req_exec_lck_resourceunlock->source.conn),
 				&res_lib_lck_resourceunlockasync,
 				sizeof (struct res_lib_lck_resourceunlockasync));
 			openais_conn_send_response (
-				resource_lock->callback_source.conn,
+				openais_conn_partner_get(resource_lock->callback_source.conn),
 				&res_lib_lck_resourceunlockasync,
 				sizeof (struct res_lib_lck_resourceunlockasync));
 		} else {
