@@ -39,10 +39,13 @@
 #include <assert.h>
 
 #include "../lcr/lcr_ifact.h"
+#include "swab.h"
 #include "service.h"
 #include "mainconfig.h"
 #include "util.h"
-#include "print.h"
+#include "logsys.h"
+
+LOGSYS_DECLARE_SUBSYS ("SERV", LOG_INFO);
 
 struct default_service {
 	char *name;
@@ -88,7 +91,7 @@ static struct default_service default_services[] = {
 	}
 };
 
-struct openais_service_handler *ais_service[128];
+struct openais_service_handler *ais_service[SERVICE_HANDLER_MAXIMUM_COUNT];
 
 /*
  * Adds a service handler to the object database
@@ -157,8 +160,6 @@ int openais_service_default_objdb_set (struct objdb_iface_ver0 *objdb)
 		}
 	}
 
-	log_init ("SERV");
-
 	for (i = 0; i < sizeof (default_services) / sizeof (struct default_service); i++) {
 		openais_service_objdb_add (objdb, default_services[i].name, default_services[i].ver);
 	}
@@ -203,6 +204,7 @@ int openais_service_link_all (struct objdb_iface_ver0 *objdb)
 		/*
 		 * reference the interface and register it
 		 */
+		iface_ver0_p = NULL;
 		lcr_ifact_reference (
 			&handle,
 			service_name,
