@@ -1,6 +1,8 @@
 /*
  * Copyright (c) 2005-2006 MontaVista Software, Inc.
  * Copyright (c) 2006 Ericsson AB.
+ * Copyright (c) 2006-2007 Red Hat, Inc.
+ *
  * Author: Steven Dake (sdake@mvista.com)
  * Author: Hans Feldt
  *
@@ -58,9 +60,11 @@
 #include "totem.h"
 #include "vsf.h"
 #include "../lcr/lcr_ifact.h"
-#include "print.h"
+#include "logsys.h"
 #include "util.h"
 
+LOGSYS_DECLARE_SUBSYS ("SYNC", LOG_INFO);
+
 #define MESSAGE_REQ_SYNC_BARRIER 0
 #define MESSAGE_REQ_SYNC_REQUEST 1
 
@@ -224,9 +228,9 @@ static void sync_callbacks_load (void)
 	int res;
 
 	ENTER("");
-// TODO rewrite this to get rid of the for (;;)
 	for (;;) {
-		res = sync_callbacks_retrieve (sync_recovery_index, &sync_callbacks);
+		res = sync_callbacks_retrieve (sync_recovery_index,
+			&sync_callbacks);
 		/*
 		 * No more service handlers have sync callbacks at this time
 		 */
@@ -290,7 +294,6 @@ int sync_register (
 	void *vsf_iface_p;
 	char openais_vsf_type[1024];
 
- 	log_init ("SYNC");
 	res = totempg_groups_initialize (
 		&sync_group_handle,
 		sync_deliver_fn,
@@ -522,6 +525,11 @@ static void sync_confchg_fn (
 
 	ENTER("");
 
+	if (configuration_type != TOTEM_CONFIGURATION_REGULAR) {
+		LEAVE("");
+		return;
+	}
+
 	/*
 	 * Save current members and ring ID for later use
 	 */
