@@ -46,16 +46,14 @@
 #include <arpa/inet.h>
 #include <sys/param.h>
 
-#include "../include/list.h"
+#include "swab.h"
+#include "list.h"
 #include "util.h"
 #include "totem.h"
 #include "totemconfig.h"
-#include "print.h"
+#include "logsys.h"
 #include "objdb.h"
-
-#if defined(OPENAIS_BSD) || defined(OPENAIS_DARWIN)
-	#define HZ 100  /* 10ms */
-#endif
+#include "tlist.h" /* for HZ */
 
 #define TOKEN_RETRANSMITS_BEFORE_LOSS_CONST	4
 #define TOKEN_TIMEOUT				1000
