@@ -4,7 +4,7 @@
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@redhat.com)
+ * Author: Steven Dake (sdake@mvista.com)
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -137,8 +137,12 @@ extern int totempg_ifaces_get (
 	char ***status,
         unsigned int *iface_count);
 
-extern int totempg_ring_reenable (void);
-	
 extern char *totempg_ifaces_print (unsigned int nodeid);
 
+extern int totempg_my_nodeid_get (void);
+
+extern int totempg_my_family_get (void);
+
+extern int totempg_ring_reenable (void);
+	
 #endif /* TOTEMPG_H_DEFINED */
