@@ -3,7 +3,7 @@
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@redhat.com)
+ * Author: Steven Dake (sdake@mvista.com)
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -34,7 +34,7 @@
 #ifndef IPC_GEN_H_DEFINED
 #define IPC_GEN_H_DEFINED
 
-#include "mar_gen.h"
+#include <mar_gen.h>
 
 enum service_types {
 	EVS_SERVICE = 0,
