@@ -1,7 +1,6 @@
 /*
- * Copyright (C) 2006-2007 Red Hat, Inc.
- *
- * Author: Steven Dake (sdake@redhat.com)
+ * Copyright (c) 2006 Steven Dake (sdake@mvista.com)
+ * Copyright (c) 2006 Sun Microsystems, Inc.
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -50,15 +49,17 @@
 #include <sys/poll.h>
 #include <string.h>
 
-#if defined(OPENAIS_LINUX)
+#if defined(OPENAIS_LINUX) || defined(OPENAIS_SOLARIS)
 /* SUN_LEN is broken for abstract namespace 
  */
 #define AIS_SUN_LEN(a) sizeof(*(a))
-
-static char *socketname = "lcr.socket";
 #else
 #define AIS_SUN_LEN(a) SUN_LEN(a)
+#endif
 
+#ifdef OPENAIS_LINUX
+static char *socketname = "lcr.socket";
+#else
 static char *socketname = "/var/run/lcr.socket";
 #endif
 
@@ -110,9 +111,14 @@ int uic_msg_send (int fd, char *msg)
 	msg_send.msg_iovlen = 2;
 	msg_send.msg_name = 0;
 	msg_send.msg_namelen = 0;
+#ifndef OPENAIS_SOLARIS
 	msg_send.msg_control = 0;
 	msg_send.msg_controllen = 0;
 	msg_send.msg_flags = 0;
+#else
+	msg_send.msg_accrights = NULL;
+	msg_send.msg_accrightslen = 0;
+#endif
 
 	retry_send:
 	res = sendmsg (fd, &msg_send, 0);
