@@ -46,12 +46,12 @@
 #include <sys/select.h>
 #include <sys/un.h>
 
-#include "../include/saAis.h"
-#include "../include/cfg.h"
-#include "../include/mar_gen.h"
-#include "../include/ipc_gen.h"
-#include "../include/ipc_cfg.h"
-#include "util.h"
+#include <saAis.h>
+#include <cfg.h>
+#include <mar_gen.h>
+#include <ipc_gen.h>
+#include <ipc_cfg.h>
+#include <ais_util.h>
 
 struct res_overlay {
 	mar_res_header_t header;
@@ -89,6 +89,10 @@ static struct saHandleDatabase cfg_hdb = {
  */
 void cfg_handleInstanceDestructor (void *instance)
 {
+	struct cfg_instance *cfg_instance = instance;
+
+	pthread_mutex_destroy (&cfg_instance->response_mutex);
+	pthread_mutex_destroy (&cfg_instance->dispatch_mutex);
 }
 
 SaAisErrorT
