@@ -46,15 +46,15 @@
 #include <sys/select.h>
 #include <sys/un.h>
 
-#include "../include/saAis.h"
-#include "../include/list.h"
-#include "../include/saCkpt.h"
-#include "../include/mar_gen.h"
-#include "../include/mar_ckpt.h"
-#include "../include/ipc_gen.h"
-#include "../include/ipc_ckpt.h"
+#include <saAis.h>
+#include <list.h>
+#include <saCkpt.h>
+#include <mar_gen.h>
+#include <mar_ckpt.h>
+#include <ipc_gen.h>
+#include <ipc_ckpt.h>
 
-#include "util.h"
+#include <ais_util.h>
 
 struct message_overlay {
 	mar_res_header_t header __attribute__((aligned(8)));
@@ -155,15 +155,24 @@ struct iteratorSectionIdListEntry {
  */
 void ckptHandleInstanceDestructor (void *instance)
 {
+	struct ckptInstance *ckptInstance = instance;
+
+	pthread_mutex_destroy (&ckptInstance->response_mutex);
+	pthread_mutex_destroy (&ckptInstance->dispatch_mutex);
 }
 
 void checkpointHandleInstanceDestructor (void *instance)
 {
-	return;
+	struct ckptCheckpointInstance *checkpointInstance = instance;
+
+	pthread_mutex_destroy (&checkpointInstance->response_mutex);
 }
 
 void ckptSectionIterationHandleInstanceDestructor (void *instance)
 {
+	struct ckptSectionIterationInstance *iterationInstance = instance;
+
+	pthread_mutex_destroy (&iterationInstance->response_mutex);
 }
 
 static void ckptSectionIterationInstanceFinalize (struct ckptSectionIterationInstance *ckptSectionIterationInstance)
