@@ -1,10 +1,10 @@
 /*
  * Copyright (c) 2002-2005 MontaVista Software, Inc.
- * Copyright (c) 2006-2007 Red Hat, Inc.
+ * Copyright (c) 2006 Red Hat, Inc.
  *
  * All rights reserved.
  *
- * Author: Steven Dake (sdake@redhat.com)
+ * Author: Steven Dake (sdake@mvista.com)
  *
  * This software licensed under BSD license, the text of which follows:
  * 
@@ -45,15 +45,16 @@
 #include <sys/select.h>
 #include <sys/un.h>
 
+#include <swab.h>
 #include "../exec/totem.h"
-#include "../include/saAis.h"
-#include "../include/saClm.h"
-#include "../include/ipc_gen.h"
-#include "../include/ipc_clm.h"
-#include "../include/mar_gen.h"
-#include "../include/mar_clm.h"
+#include <saAis.h>
+#include <saClm.h>
+#include <ipc_gen.h>
+#include <ipc_clm.h>
+#include <mar_gen.h>
+#include <mar_clm.h>
 
-#include "util.h"
+#include <ais_util.h>
 
 struct res_overlay {
 	mar_res_header_t header;
@@ -92,6 +93,10 @@ static struct saVersionDatabase clmVersionDatabase = {
 
 void clmHandleInstanceDestructor (void *instance)
 {
+	struct clmInstance *clmInstance = instance;
+
+	pthread_mutex_destroy (&clmInstance->response_mutex);
+	pthread_mutex_destroy (&clmInstance->dispatch_mutex);
 }
 
 
@@ -494,9 +499,6 @@ saClmFinalize (
 	clmInstance->finalize = 1;
 
 	pthread_mutex_unlock (&clmInstance->response_mutex);
-	pthread_mutex_destroy (&clmInstance->response_mutex);
-
-	pthread_mutex_destroy (&clmInstance->dispatch_mutex);
 
 	saHandleDestroy (&clmHandleDatabase, clmHandle);
 
