@@ -46,11 +46,12 @@
 #include <sys/socket.h>
 #include <errno.h>
 
+#include <swab.h>
 #include "../exec/totem.h"
-#include "../include/saAis.h"
-#include "../include/evs.h"
-#include "../include/ipc_evs.h"
-#include "util.h"
+#include <saAis.h>
+#include <evs.h>
+#include <ipc_evs.h>
+#include <ais_util.h>
 
 struct evs_inst {
 	int response_fd;
@@ -80,6 +81,10 @@ static struct saHandleDatabase evs_handle_t_db = {
  */
 static void evs_instance_destructor (void *instance)
 {
+	struct evs_inst *evs_inst = instance;
+
+	pthread_mutex_destroy (&evs_inst->response_mutex);
+	pthread_mutex_destroy (&evs_inst->dispatch_mutex);
 }
 
 
