@@ -45,13 +45,13 @@
 #include <sys/select.h>
 #include <sys/un.h>
 
-#include "../include/saAis.h"
-#include "../include/list.h"
-#include "../include/saLck.h"
-#include "../include/ipc_gen.h"
-#include "../include/ipc_lck.h"
+#include <saAis.h>
+#include <list.h>
+#include <saLck.h>
+#include <ipc_gen.h>
+#include <ipc_lck.h>
 
-#include "util.h"
+#include <ais_util.h>
 
 struct message_overlay {
 	mar_res_header_t header __attribute__((aligned(8)));
@@ -143,11 +143,14 @@ static struct saVersionDatabase lckVersionDatabase = {
  */
 void lckHandleInstanceDestructor (void *instance)
 {
+	struct lckInstance *lckInstance = instance;
+
+	pthread_mutex_destroy (&lckInstance->response_mutex);
+	pthread_mutex_destroy (&lckInstance->dispatch_mutex);
 }
 
 void lckResourceHandleInstanceDestructor (void *instance)
 {
-	return;
 }
 
 void lckResourceHandleLockIdInstanceDestructor (void *instance)
@@ -340,7 +343,7 @@ saLckDispatch (
 	struct message_overlay dispatch_data;
 	struct res_lib_lck_lockwaitercallback *res_lib_lck_lockwaitercallback;
 	struct res_lib_lck_resourceopenasync *res_lib_lck_resourceopenasync = NULL;
-	struct res_lib_lck_resourcelockasync *res_lib_lck_resourcelockasync;
+	struct res_lib_lck_resourcelockasync *res_lib_lck_resourcelockasync = NULL;
 	struct res_lib_lck_resourceunlockasync *res_lib_lck_resourceunlockasync;
 
 
@@ -519,6 +522,17 @@ saLckDispatch (
 			callbacks.saLckResourceUnlockCallback (
 				res_lib_lck_resourceunlockasync->invocation,
 				res_lib_lck_resourceunlockasync->header.error);
+
+			if (res_lib_lck_resourcelockasync->header.error == SA_AIS_OK) {
+				error = saHandleInstanceGet (&lckLockIdHandleDatabase,
+							     res_lib_lck_resourceunlockasync->lockId,
+							     (void *)&lckLockIdInstance);
+				if (error == SA_AIS_OK) {
+					saHandleInstancePut (&lckLockIdHandleDatabase, res_lib_lck_resourceunlockasync->lockId);
+
+					saHandleDestroy (&lckLockIdHandleDatabase, res_lib_lck_resourceunlockasync->lockId);
+				}
+			}
 			break;
 #ifdef NOT_DONE_YET
 
@@ -654,9 +668,9 @@ saLckResourceOpen (
 	req_lib_lck_resourceopen.header.size = sizeof (struct req_lib_lck_resourceopen);
 	req_lib_lck_resourceopen.header.id = MESSAGE_REQ_LCK_RESOURCEOPEN;
 
-	memcpy (&req_lib_lck_resourceopen.lockResourceName, lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourceopen.lockResourceName, (SaNameT *)lockResourceName);
 
-	memcpy (&lckResourceInstance->lockResourceName, lockResourceName, sizeof (SaNameT));
+	memcpy (&lckResourceInstance->lockResourceName, lockResourceName, sizeof(SaNameT));
 	req_lib_lck_resourceopen.resourceOpenFlags = resourceOpenFlags;
 	req_lib_lck_resourceopen.resourceHandle = *lckResourceHandle;
 	req_lib_lck_resourceopen.async_call = 0;
@@ -793,8 +807,8 @@ saLckResourceClose (
 
 	req_lib_lck_resourceclose.header.size = sizeof (struct req_lib_lck_resourceclose);
 	req_lib_lck_resourceclose.header.id = MESSAGE_REQ_LCK_RESOURCECLOSE;
-	memcpy (&req_lib_lck_resourceclose.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourceclose.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourceclose.resourceHandle = lckResourceHandle;
 
 	pthread_mutex_lock (lckResourceInstance->response_mutex);
@@ -861,8 +875,8 @@ saLckResourceLock (
 
 	req_lib_lck_resourcelock.header.size = sizeof (struct req_lib_lck_resourcelock);
 	req_lib_lck_resourcelock.header.id = MESSAGE_REQ_LCK_RESOURCELOCK;
-	memcpy (&req_lib_lck_resourcelock.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourcelock.lockMode = lockMode;
 	req_lib_lck_resourcelock.lockFlags = lockFlags;
 	req_lib_lck_resourcelock.waiterSignal = waiterSignal;
@@ -954,8 +968,8 @@ saLckResourceLockAsync (
 
 	req_lib_lck_resourcelock.header.size = sizeof (struct req_lib_lck_resourcelock);
 	req_lib_lck_resourcelock.header.id = MESSAGE_REQ_LCK_RESOURCELOCKASYNC;
-	memcpy (&req_lib_lck_resourcelock.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourcelock.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 	req_lib_lck_resourcelock.lockMode = lockMode;
 	req_lib_lck_resourcelock.lockFlags = lockFlags;
 	req_lib_lck_resourcelock.waiterSignal = waiterSignal;
@@ -1024,8 +1038,8 @@ saLckResourceUnlock (
 		return (error);
 	}
 
-	memcpy (&req_lib_lck_resourceunlock.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 
 	saHandleInstancePut (&lckResourceHandleDatabase,
 		lckLockIdInstance->lckResourceHandle);
@@ -1082,8 +1096,8 @@ saLckResourceUnlockAsync (
 		return (error);
 	}
 
-	memcpy (&req_lib_lck_resourceunlock.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_resourceunlock.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 
 	saHandleInstancePut (&lckResourceHandleDatabase,
 		lckLockIdInstance->lckResourceHandle);
@@ -1130,8 +1144,8 @@ saLckLockPurge (
 
 	req_lib_lck_lockpurge.header.size = sizeof (struct req_lib_lck_lockpurge);
 	req_lib_lck_lockpurge.header.id = MESSAGE_REQ_LCK_LOCKPURGE;
-	memcpy (&req_lib_lck_lockpurge.lockResourceName,
-		&lckResourceInstance->lockResourceName, sizeof (SaNameT));
+	marshall_to_mar_name_t (&req_lib_lck_lockpurge.lockResourceName,
+		&lckResourceInstance->lockResourceName);
 
 	pthread_mutex_lock (lckResourceInstance->response_mutex);
 
