@@ -45,13 +45,13 @@
 #include <sys/select.h>
 #include <sys/un.h>
 
-#include "../include/saAis.h"
-#include "../include/list.h"
-#include "../include/saMsg.h"
-#include "../include/ipc_gen.h"
-#include "../include/ipc_msg.h"
+#include <saAis.h>
+#include <list.h>
+#include <saMsg.h>
+#include <ipc_gen.h>
+#include <ipc_msg.h>
 
-#include "util.h"
+#include <ais_util.h>
 
 struct message_overlay {
 	mar_res_header_t header __attribute__((aligned(8)));
@@ -130,11 +130,14 @@ struct iteratorSectionIdListEntry {
  */
 void msgHandleInstanceDestructor (void *instance)
 {
+	struct msgInstance *msgInstance = instance;
+
+	pthread_mutex_destroy (&msgInstance->response_mutex);
+	pthread_mutex_destroy (&msgInstance->dispatch_mutex);
 }
 
 void queueHandleInstanceDestructor (void *instance)
 {
-	return;
 }
 
 #ifdef COMPILE_OUT
