@@ -53,9 +53,9 @@
 #include <netinet/in.h>
 #include <assert.h>
 
-#include "../include/saAis.h"
-#include "../include/ipc_gen.h"
-#include "util.h"
+#include <saAis.h>
+#include <ipc_gen.h>
+#include <ais_util.h>
 
 enum SA_HANDLE_STATE {
 	SA_HANDLE_STATE_EMPTY,
